@@ -47,6 +47,7 @@ from xml.dom.minidom import Node
 import hildon
 import dbus.glib
 import cairo
+import time
 
 gobject.threads_init()
 from dbus import glib
@@ -58,6 +59,8 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.18"
 """
+0.18-3
+    speed up what I can
 0.18-2
     plugin[google_routesearch] add more icons
     clien up distanse recalculation
@@ -181,6 +184,10 @@ CONFIG = {
 
     }
 
+timing_plugins = 0
+timing_osd = 0
+
+
 
 maps_source = [
     [osmgpsmap.SOURCE_OPENSTREETMAP, "OpenStreetMap I"],
@@ -475,27 +482,22 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         self.plugin_ico_h = 60
         self.plugin_ico_test = 48
 
+        self.pb_plus = cairo.ImageSurface.create_from_png( './imgs/i_plus.png' )
+        self.pb_min = cairo.ImageSurface.create_from_png( './imgs/i_min.png' )
+        self.pb_gps_on = cairo.ImageSurface.create_from_png( './imgs/i_gps_on.png' )
+        self.pb_gps = cairo.ImageSurface.create_from_png( './imgs/i_gps.png' )
+        self.pb_menu = cairo.ImageSurface.create_from_png( './imgs/ico_work_64_64.png' )
+        
+
     def do_draw(self, gpsmap, gdkdrawable):
         #return None
-
+        if timing_osd:
+            t = time.time()
+        
         self.size = gdkdrawable.get_size()
-
-        cr = gdkdrawable.cairo_create()
-
-        try:
-            if self.pp_plus:
-                pass
-        except:
-            self.pb_plus = cairo.ImageSurface.create_from_png( './imgs/i_plus.png' )
-            self.pb_min = cairo.ImageSurface.create_from_png( './imgs/i_min.png' )
-            self.pb_gps_on = cairo.ImageSurface.create_from_png( './imgs/i_gps_on.png' )
-            self.pb_gps = cairo.ImageSurface.create_from_png( './imgs/i_gps.png' )
-            self.pb_menu = cairo.ImageSurface.create_from_png( './imgs/ico_work_64_64.png' )
-
-        #pb_c.render_to_drawable( gdkdrawable, gc, 0,0,100,100,pb_c.get_width(),pb_c.get_height(),0,0,0 )
-
         x = self.size[0]-64
 
+        cr = gdkdrawable.cairo_create()
 
         cr.set_source_surface( self.pb_plus, x,10 )
         cr.paint()
@@ -508,7 +510,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
             cr.paint()
 
             try:
-               self.osmMapa.osm.props.gps_track_highlight_radius = (gps.accuracy/gps.acc_scale[self.osmMapa.osm.props.zoom])*10
+                self.osmMapa.osm.props.gps_track_highlight_radius = (gps.accuracy/gps.acc_scale[self.osmMapa.osm.props.zoom])*10
             except:
                 self.osmMapa.osm.props.gps_track_highlight_radius = 0
                 print "GPS manager: accurasy is insain (",self.accuracy,")"
@@ -519,7 +521,6 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         cr.set_source_surface( self.pb_menu, x,self.size[1]-100 )
         cr.paint()
 
-
         plug_nr = 0
         for plugin in self.osmMapa.plugins_list:
             plugin_name = plugin[1]
@@ -541,7 +542,8 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
             cr.set_font_size(15)
             cr.move_to(10,15)
             cr.show_text(str)
-
+        if timing_osd:
+            print "YosmapaOSD do_draw in:",(time.time()-t)
         return None
 
     def do_render(self, gpsmap):
@@ -551,6 +553,8 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         return False
 
     def do_button_press(self, gpsmap, gdkeventbutton):
+        if timing_osd:
+            t = time.time()
         #print "dummy event ",gpsmap, gdkeventbutton
         x = self.size[0]-64
         #print "x start",x,"bt press at",gdkeventbutton.x
@@ -645,7 +649,8 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                     m.show_all()
                     m.popup( None, None, None , 2, 0)
 
-
+        if timing_osd:
+            print "YosmapaOSD press in:",( time.time()-t )
         return False
 
     def on_route_to_it(self, w, lat, lon):
@@ -883,13 +888,14 @@ class UI(gtk.Window):
             dis = self.distance_to_string( self.distance( latc, lonc, lat, lon) )
             cr.show_text("%s"%dis)
 
+    def draw_cloud_byll(self, cr, lat, lon, str, font_size = 13, Fifek = True):
+        x,y = self.osm.geographic_to_screen(lat,lon)
+        self.draw_cloud(cr, x, y, str, font_size, Fifek)
     def draw_cloud(self, cr, x, y, str, font_size = 13, Fifek = True):
-        if x<0 or y<0:
-            return None
-        rlat, rlon = self.osm.get_co_ordinates(int(x), int(y))
-        if str == "":
+        if x<0 or y<0 or str == "":
             return None
 
+        rlat, rlon = self.osm.get_co_ordinates(int(x), int(y))
         cr.select_font_face("Georgia")
         cr.set_font_size(font_size)
         xbearing, ybearing, width, height, xadvance, yadvance = cr.text_extents( str )
@@ -924,6 +930,7 @@ class UI(gtk.Window):
         y+=10
         height+=4
         width+=4
+        
         cr.arc (x + width - radius, y + radius, radius, -90 * degrees, 0 * degrees)
         cr.arc (x + width - radius, y + height - radius, radius, 0 * degrees, 90 * degrees)
         cr.arc (x + radius, y + height - radius, radius, 90 * degrees, 180 * degrees)
@@ -936,9 +943,6 @@ class UI(gtk.Window):
         cr.set_line_width (1.0)
         cr.stroke ()
 
-        cr.set_source_rgb(0.0, 0.0, 0.0)
-        cr.select_font_face("Georgia")
-        cr.set_font_size(font_size)
         if multiline:
             line_nr = 0
             for l in tmp:
@@ -952,8 +956,8 @@ class UI(gtk.Window):
 
 
         self.clikable_clouds.append( [ x,y,x+width,y+height, float(math.degrees(rlat)), float(math.degrees(rlon)) ] )
-
-
+        
+        return True
 
     def point_test(self, lat, lon, x,y):
         return False
@@ -1180,15 +1184,24 @@ class PluginsLayer(gobject.GObject, osmgpsmap.GpsMapLayer):
         self.plugins = plugins
 
     def do_draw(self, gpsmap, gdkdrawable):
+        
+        if timing_plugins:
+            t = time.time()
+            
         if CONFIG['work_work_work']:
             self.osmMapa.clikable_clouds = []
             for plugin in self.plugins:
                 if CONFIG[plugin[1]]:
                     try:
+                        if timing_plugins:                            
+                            tp = time.time()
                         plugin[0].do_draw(gpsmap, gdkdrawable)
+                        if timing_plugins:
+                            print "plugin ", plugin[1]," in ",(time.time()-tp)
                     except Exception, e:
                         print "PluginsLayer do_draw ERROR (",plugin[1],"):", e
-
+        if timing_plugins:
+            print "PluginsLayers in",(time.time()-t)
 
     def do_render(self, gpsmap):
         pass
